translate.misc.wStringIO.StringIO

Package translate :: Package misc :: Module wStringIO :: Class StringIO |
[hide private]
[frames] | no frames]

# Class StringIO

source code

Instance Methods | [hide private]
__init__(self, buf=`'````'`) | source code
__iter__(self) | source code
next(self) | source code
close(self) Free the memory buffer. | source code
isatty(self) | source code
seek(self, pos, mode=0) | source code
tell(self) | source code
read(self, n=None) | source code
readline(self, length=None) | source code
readlines(self) | source code
truncate(self, size=None) | source code
write(self, s) | source code
writelines(self, lines) | source code
flush(self) | source code
getvalue(self) | source code